@@ -10,8 +10,8 @@ export KF6_PREFIX=/opt/kf6
 [ ! -f /etc/profile.d/xorg.sh ] && echo "Installing xorg_build_env" && extension --install xorg_build_env && echo "Finished xorg_build_env"
 source /etc/profile.d/xorg.sh
 
-[[ $(cat /usr/share/ECM/cmake/ECMConfigVersion.cmake | grep "6.13.0") == "" ]] && echo "Installing extra_cmake_modules:6.13.0" && extension --install extra_cmake_modules:6.13.0 && echo "Finished extra_cmake_modules:6.13.0"
-[ ! -d /usr/share/icons/breeze ] && echo "Installing kde_breeze_icons:6.13.0" && extension --install kde_breeze_icons:6.13.0 && echo "Finished kde_breeze_icons:6.13.0"
+[[ $(cat /usr/share/ECM/cmake/ECMConfigVersion.cmake | grep "6.14.0") == "" ]] && echo "Installing extra_cmake_modules:6.14.0" && extension --install extra_cmake_modules:6.14.0 && echo "Finished extra_cmake_modules:6.14.0"
+[[ $(cat /etc/extension/installed_version.list | grep breeze_icons=6.14.0) == "" ]] && echo "Installing kde_breeze_icons:6.14.0" && extension --install kde_breeze_icons:6.14.0 && echo "Finished kde_breeze_icons:6.14.0"
 [ ! -d /etc/xml ] && echo "Installing docbook4_xml:4.5" && extension --install docbook4_xml:4.5 && echo "Finished docbook4_xml:4.5"
 [ ! -d /usr/share/xml/docbook/xsl-stylesheets-nons-* ] && echo "Installing docbook_xsl_nons" && extension --install docbook_xsl_nons && echo "Finished docbook_xsl_nons"
 [[ $(command -v canberra-gtk-play) == "" ]] && echo "Installing libcanberra" && extension --install libcanberra && echo "Finished libcanberra"
@@ -20,13 +20,14 @@ source /etc/profile.d/xorg.sh
 [[ $(command -v xsltproc) == "" ]] && echo "Installing libxslt" && extension --install libxslt && echo "Finished libxslt"
 [[ $(command -v mdb_stat) == "" ]] && echo "Installing lmdb" && extension --install lmdb && echo "Finished lmdb"
 [[ $(command -v qcatool-qt6) == "" ]] && echo "Installing qca" && extension --install qca && echo "Finished qca"
-[[ $(command -v qrencode) == "" ]] && echo "Installing qrencode" && extension --install qrencode && echo "Finished qrencode"
+[[ $(command -v qrencode) == "" ]] && echo "Installing libqrencode" && extension --install libqrencode && echo "Finished libqrencode"
 #[[ $(cat /etc/extension/installed_version.list | grep "plasma_wayland_protocols=1.18.0") == "" ]] && echo "Installing plasma_wayland_protocols:1.18.0" && extension --install plasma_wayland_protocols:1.18.0 && echo "Finished plasma_wayland_protocols:1.18.0"
 [ ! -d /usr/share/plasma-wayland-protocols ] && echo "Installing plasma_wayland_protocols" && extension --install plasma_wayland_protocols && echo "Finished plasma_wayland_protocols"
 [ ! -d /usr/lib/python*/site-packages/pyyaml-* ] && echo "Installing py_pyyaml" && extension --install py_pyyaml && echo "Finished py_pyyaml"
 [[ $(command -v update-mime-database) == "" ]] && echo "Installing shared_mime_info" && extension --install shared_mime_info && echo "Finished shared_mime_info"
 [ ! -f  /usr/lib/perl5/*/site_perl/URI.pm ] && echo "Installing perl_uri" && extension --install perl_uri && echo "Finished perl_uri"
 [[ $(command -v wget) == "" ]] && echo "Installing wget" && extension --install wget && echo "Finished wget"
+[[ $(command -v secret-tool) == "" ]] && echo "Installing libsecret" && extension --install libsecret && echo "Finished libsecret"
 
 # Recommended
 if [[ $INSTALL_RECOMMENDED != false ]]; then 
@@ -43,7 +44,7 @@ fi
 # Furthermore, the instructions below assume that the environment has been set up as described in Introduction to KF6.
 
 # Optional
-if [[ $INSTALL_OPTIONAL != false ]]; then	
+if [[ $INSTALL_OPTIONAL != false ]]; then 
 	# BlueZ-5.79 (needed to build Bluez-Qt) and Datamatrix (deemed recommended for Prison by upstream)
 	[[ $(command -v btmon) == "" ]] && echo "Installing bluez" && extension --install bluez && echo "Finished bluez"
 fi
@@ -68,14 +69,14 @@ fi
 #[[ $(command -v libheif) == "" ]] && echo "Installing libheif" && extension --install libheif && echo "Finished libheif"
 
 # Optional dependencies for Solid
-if [[ $INSTALL_OPTIONAL != false ]]; then
+if [[ $INSTALL_OPTIONAL != false ]]; then 
 	# UDisks-2.10.1, UPower-1.90.7 and media-player-info (runtime)
 	[[ $(command -v udisksctl) == "" ]] && echo "Installing udisks" && extension --install udisks && echo "Finished udisks"
 	[[ $(command -v upower) == "" ]] && echo "Installing upower" && extension --install upower && echo "Finished upower"
 fi
 
 # Optional dependency for KWallet
-if [[ $INSTALL_OPTIONAL != false ]]; then
+if [[ $INSTALL_OPTIONAL != false ]]; then 
 	# GPGME-1.24.2, built with C++ bindings (which is the default).
 	[[ $(command -v gpgme-tool) == "" ]] && echo "Installing gpgme" && extension --install gpgme && echo "Finished gpgme"
 fi
@@ -83,7 +84,7 @@ fi
 # Optional dictionary backends for Sonnet
 # Hspell and Hunspell
 
-if [ $BUILD_ALL == "false" ] && [ ! -f /opt/kf6/bin/kded6 ]; then
+if [ $BUILD_ALL == "false" ] && [ ! -d /opt/kf6-6.14.0 ]; then
 	echo "kde_framework _"								>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
