@@ -1,6 +1,6 @@
 DESCRIPTION="KDE Frameworks is a collection of libraries based on top of Qt6 and QML derived from the previous KDE libraries."
 
-EXT_VERSION=6.13.0
+EXT_VERSION=6.14.0
 
 # KDE Frameworks 6 Pre-installation Configuration
 #export KF6_PREFIX=/opt/kf6
@@ -58,6 +58,21 @@ fi
 [ -h $KF6_PREFIX/share/dbus-1 ] && unlink $KF6_PREFIX/share/dbus-1
 [ -h $KF6_PREFIX/share/polkit-1 ] && unlink $KF6_PREFIX/share/polkit-1
 [ -h $KF6_PREFIX/lib/systemd ] && unlink $KF6_PREFIX/lib/systemd
+[ -d $KF6_PREFIX/lib/systemd ] && rm -r $KF6_PREFIX/lib/systemd
+
+[ -h /opt/kf6 ] && unlink /opt/kf6
+
+[ -d /opt/kf6.old ] && rm -r /opt/kf6.old
+
+if [ -d /opt/kf6 ]; then
+	mv -v /opt/kf6 /opt/kf6.old                         &&
+	install -v -dm755           $KF6_PREFIX/{etc,share} &&
+	ln -sfv /etc/dbus-1         $KF6_PREFIX/etc         &&
+	ln -sfv /usr/share/dbus-1   $KF6_PREFIX/share       &&
+	ln -sfv /usr/share/polkit-1 $KF6_PREFIX/share       &&
+	install -v -dm755           $KF6_PREFIX/lib         &&
+	ln -sfv /usr/lib/systemd    $KF6_PREFIX/lib
+fi
 
 install -v -dm755           $KF6_PREFIX/{etc,share}
 ln -sfv /etc/dbus-1         $KF6_PREFIX/etc
@@ -79,98 +94,86 @@ ln -sfv /usr/share/icons/hicolor $KF6_PREFIX/share/icons
 
 
 
-url=https://download.kde.org/stable/frameworks/6.13/
+url=https://download.kde.org/stable/frameworks/6.14/
 wget -r -nH -nd -A '*.xz' -np $url
 
 cat > frameworks-${EXT_VERSION}.md5 << "EOF"
-c12ac706d1f5b1cde0b65c7f8d74288f  attica-6.13.0.tar.xz
-#fffa4105250ef446219808e275c754a5  extra-cmake-modules-6.13.0.tar.xz
-9adefdfc46c805f55f2c2736d118f5a5  kapidox-6.13.0.tar.xz
-8c54e968cd52480bb5c7dc5dd262bba6  karchive-6.13.0.tar.xz
-f8fe4baf7745a75028a4d063aadb768c  kcodecs-6.13.0.tar.xz
-eeb0d97e29b84f9f58977e90d24f23ee  kconfig-6.13.0.tar.xz
-42ea67c66d76712a359df6b6a4d271c1  kcoreaddons-6.13.0.tar.xz
-dd53aa26b08bb275f17503959815bde2  kdbusaddons-6.13.0.tar.xz
-0276c48fe10629c5f97efc46444a2201  kdnssd-6.13.0.tar.xz
-0b00b7489887eee35c0f105d65a8b4ed  kguiaddons-6.13.0.tar.xz
-bcc51ec7d2dfaa68465947e54babf61e  ki18n-6.13.0.tar.xz
-89b25fac6b75ced80c9fbb8189412e0d  kidletime-6.13.0.tar.xz
-ba7a2ca96b4df6025619bd58f452b4e6  kimageformats-6.13.0.tar.xz
-c6d84368fa1476c1be44ea8f8e80bb4a  kitemmodels-6.13.0.tar.xz
-70089619a94a0e81264c8d487e7251e0  kitemviews-6.13.0.tar.xz
-be1f5afd4ac09d2361ed0162d872e970  kplotting-6.13.0.tar.xz
-8b7586ba8a39718b261b8626d0dbf8ef  kwidgetsaddons-6.13.0.tar.xz
-9ff25f2b5a06c4531efb01ae5c5d7deb  kwindowsystem-6.13.0.tar.xz
-7fe8caa8f457ed9ff2e3441681ee39a8  networkmanager-qt-6.13.0.tar.xz
-3e03e17c5d4ed73fda022e5d022a5634  solid-6.13.0.tar.xz
-086d95b6c3ca5662da495a20e70d1046  sonnet-6.13.0.tar.xz
-8b661df05c7f2c81cda0560dd4a45e34  threadweaver-6.13.0.tar.xz
-2a58610e2d92e94c26d4e5bcd099d653  kauth-6.13.0.tar.xz
-41c89f6e166a810fdcbe2ea9a0235822  kcompletion-6.13.0.tar.xz
-1d4c0b59d2706a4cc953ebb3097f2493  kcrash-6.13.0.tar.xz
-34fd06a35b7ae7e4ae8a95848b057d2e  kdoctools-6.13.0.tar.xz
-5639de35d027d25d5c2537049fa8e1ef  kpty-6.13.0.tar.xz
-dc9f9408462a03b232c6492a5c08ddea  kunitconversion-6.13.0.tar.xz
-c02d1db1cc46785a786603d3e262a5aa  kcolorscheme-6.13.0.tar.xz
-60ee97fd70d698e8e5318a4f82eb3bb4  kconfigwidgets-6.13.0.tar.xz
-7b1616897f802d98b7432edf604285bb  kservice-6.13.0.tar.xz
-487332e4e629411e4ebfd6c4ee65c93b  kglobalaccel-6.13.0.tar.xz
-b7a158ee246a694296193f2fdad0a75c  kpackage-6.13.0.tar.xz
-2ba3e12c09523a06fd9c7c41f61276bc  kdesu-6.13.0.tar.xz
-6982b13fb92ae3792eb16aefd5980088  kiconthemes-6.13.0.tar.xz
-3a06c30f46d48292bbe65bcbde3ea175  knotifications-6.13.0.tar.xz
-d1d0caa9fe35d2c34d15d448dc1022ee  kjobwidgets-6.13.0.tar.xz
-1e8f264d42649f8a3288742ed2a757a1  ktextwidgets-6.13.0.tar.xz
-e722e89631cbaa69a206551a8a66dbd3  kxmlgui-6.13.0.tar.xz
-0e9fcbf3f244f3e66d150cf78acfd452  kbookmarks-6.13.0.tar.xz
-6d40ad91d72406c3e8b1d55655cc35f0  kwallet-6.13.0.tar.xz
-472202ec46a6c0b4a838b6143d6a0d60  kded-6.13.0.tar.xz
-632f38fc7601e22dc231793d902c6292  kio-6.13.0.tar.xz
-0b76489ddb1c86ba0a9d5abdee0022a4  kdeclarative-6.13.0.tar.xz
-45e133f0a42359578160331ac0e2a26c  kcmutils-6.13.0.tar.xz
-9659239b81fd0266fbec52eddeaa6029  kirigami-6.13.0.tar.xz
-d1bcb046907203a9ad484a269c4aee81  syndication-6.13.0.tar.xz
-af414da3f21e43288d8ca394477c0c73  knewstuff-6.13.0.tar.xz
-f7f9cd13902679ef605eb76293bcf6b9  frameworkintegration-6.13.0.tar.xz
-c45e7383a99b52e2e1ae2307b51acd06  kparts-6.13.0.tar.xz
-ba7c5298c3f81f21d30f591b3d4f4859  syntax-highlighting-6.13.0.tar.xz
-bcc08aa21ba552bbefe2a8c97d4027e3  ktexteditor-6.13.0.tar.xz
-fd872dfb6c662475972b2cab44cad03d  modemmanager-qt-6.13.0.tar.xz
-b723cd0d7991dcab82b59ef2b6cc65d8  kcontacts-6.13.0.tar.xz
-2b2c2fd028cbc4256ecae04362d1f304  kpeople-6.13.0.tar.xz
-756838cb9d946e06ac8fb6cb9fde57dc  bluez-qt-6.13.0.tar.xz
-45779ed91f44700ff9d80082bb1c3843  kfilemetadata-6.13.0.tar.xz
-c23b73568aeee9aa5f9afec7def9e15d  baloo-6.13.0.tar.xz
-#48fc3036c91eed1fd8d89efb83d9494c  breeze-icons-6.13.0.tar.xz
-36ff81ebcdb1988eb272bf27f0dfc035  krunner-6.13.0.tar.xz
-##ca5266e18d3d15c089031a896401421e  prison-6.13.0.tar.xz
-6ea9727a9a2968f03da3e5e3d549eed3  qqc2-desktop-style-6.13.0.tar.xz
-4233fd805137aa1a8c8faf2c8b5d71a0  kholidays-6.13.0.tar.xz
-02b90cd4bbed0a86e3eb1c66ea0cb0ec  purpose-6.13.0.tar.xz
-0b19cdb1039bd146c45a6d5cc7099e60  kcalendarcore-6.13.0.tar.xz
-9727025fec963329082c5d29bfd85b23  kquickcharts-6.13.0.tar.xz
-6e2ba94485d3773e4b21645d131646e3  knotifyconfig-6.13.0.tar.xz
-5729859a76b5feecc9a115bd6dad91b3  kdav-6.13.0.tar.xz
-c8475b31a270bd47a8f10e4d383af7d6  kstatusnotifieritem-6.13.0.tar.xz
-dd3f65c9d10991d7fded37c9d51fb956  ksvg-6.13.0.tar.xz
-61d5d199dacd67a4689137634ae171d8  ktexttemplate-6.13.0.tar.xz
-3a9e9345e06be417fb087d3fc1274181  kuserfeedback-6.13.0.tar.xz
+165b163ab7231c7579e8333cde03e43f  attica-6.14.0.tar.xz
+#0787f26f7ba5921ac665393644828843  extra-cmake-modules-6.14.0.tar.xz
+ccb6639d36a854c80347491d2bf2f76f  kapidox-6.14.0.tar.xz
+635d1098c7eb0571d6db43f0ff934b55  karchive-6.14.0.tar.xz
+d0e8fe67e4ac9bd9f49737b5340d2766  kcodecs-6.14.0.tar.xz
+84762f48c328e4e34fc4b0765829e9c7  kconfig-6.14.0.tar.xz
+811a6a54570a0faee779ba6a9e01fd36  kcoreaddons-6.14.0.tar.xz
+174b64417eddd97bcf954ebad7e3c784  kdbusaddons-6.14.0.tar.xz
+76b0993c28f3f2e9423a459e8ec080b7  kdnssd-6.14.0.tar.xz
+e00cc2feb8c55d4d864f089c33bf10c1  kguiaddons-6.14.0.tar.xz
+6516d15a1e34e4caef35d69607a95663  ki18n-6.14.0.tar.xz
+0a9a1c022909d4be6d9fb310ede1ebe6  kidletime-6.14.0.tar.xz
+00f8aeb62b6ca6c7011e56cf136aa668  kimageformats-6.14.0.tar.xz
+ea2ab0d7af7a70b95cb347b989bdad92  kitemmodels-6.14.0.tar.xz
+87ba844368f4590b1fbdeac4227a9cae  kitemviews-6.14.0.tar.xz
+fa4eaadde19a5bfe8407182764a25092  kplotting-6.14.0.tar.xz
+366bf57822d020c18acfc8f63bb53f83  kwidgetsaddons-6.14.0.tar.xz
+bd6b50cdfa4aa40abd607df7bf3ae4aa  kwindowsystem-6.14.0.tar.xz
+6eda7f687ea9314424250bdf765e2d52  networkmanager-qt-6.14.0.tar.xz
+b2fa74433e5e5e0d17b11a537ae41065  solid-6.14.0.tar.xz
+13c0e8170ddee46d653b823253ef6d8e  sonnet-6.14.0.tar.xz
+5f3567dae998ca69fb8faa1d1ea68d10  threadweaver-6.14.0.tar.xz
+c04d4e01cc1fe0887e141c5c1c2bf404  kauth-6.14.0.tar.xz
+4b60cb0247130a5a24300602d76f8949  kcompletion-6.14.0.tar.xz
+d5a2404c2758121d1c4e4a2c925f3377  kcrash-6.14.0.tar.xz
+c0dcccda17da7f0cd91825cdb118329c  kdoctools-6.14.0.tar.xz
+8ceea0f0cec2302e129ff9ae083d5ffd  kpty-6.14.0.tar.xz
+57f619d9ccf7ce3ffb0d93d266d859f7  kunitconversion-6.14.0.tar.xz
+617ffe585b74182c6f9a0027d5697901  kcolorscheme-6.14.0.tar.xz
+88b6095c098d17133fc232a1659d19aa  kconfigwidgets-6.14.0.tar.xz
+70abb8a3d32edf9857e4737ece175203  kservice-6.14.0.tar.xz
+67c39da521e6c210c10f44ae75863280  kglobalaccel-6.14.0.tar.xz
+7118b11f803789752c1a75950ecdb38d  kpackage-6.14.0.tar.xz
+3a82ad4d22a4093f21cd307ac6bdd2fd  kdesu-6.14.0.tar.xz
+72b42af34f39df0d67a3511f03fbff89  kiconthemes-6.14.0.tar.xz
+622456f274b76ac109d89be325ce3ff4  knotifications-6.14.0.tar.xz
+0ba764fd88af1496c7912e9389b75a75  kjobwidgets-6.14.0.tar.xz
+0ce0016f7fdebd1b713dd65718e35c6e  ktextwidgets-6.14.0.tar.xz
+ad0c09af97b5af01212a2240b5be6644  kxmlgui-6.14.0.tar.xz
+e3fa434a1a03b9078adcb81bfc767fa4  kbookmarks-6.14.0.tar.xz
+#5b399f3c9bbeabc0d434ee553c34e3f1  kwallet-6.14.0.tar.xz
+530b1253870e37f75a4af218cf889009  kwallet-6.14.1.tar.xz
+428d0e0fa19edbfcb7a5e320d36e412f  kded-6.14.0.tar.xz
+cc0bd4a38d4b9b6080f8e11c22c634df  kio-6.14.0.tar.xz
+28909eaeb864dbf762ceac989e9da424  kdeclarative-6.14.0.tar.xz
+b6a713ea7a86a4b4ba9f7c26c88ffb52  kcmutils-6.14.0.tar.xz
+#120b16d889b47e2ca1327c3cab9d35b7  kirigami-6.14.0.tar.xz
+0dc8ea23799490bbf90fb7bb8f4f72dc  kirigami-6.14.1.tar.xz
+c1d0267acf6c72829a5ed6ac7e49152c  syndication-6.14.0.tar.xz
+b3d81b1c184b127d677119f7a7282f79  knewstuff-6.14.0.tar.xz
+64b921db085ff48276e6ee8da45d582f  frameworkintegration-6.14.0.tar.xz
+6a6b11193703838208b96bf11bd22259  kparts-6.14.0.tar.xz
+aba286f4bf7de433e096eb3458e847bb  syntax-highlighting-6.14.0.tar.xz
+db2c03bb09b44aed962f8497651d0748  ktexteditor-6.14.0.tar.xz
+7d430d7a3f90864cd2ca86b57d1706b8  modemmanager-qt-6.14.0.tar.xz
+0b6db4db21e997fc14ca177d8f62e0b8  kcontacts-6.14.0.tar.xz
+25aa937b849fd9ae69932c41b17d6bf5  kpeople-6.14.0.tar.xz
+b24408cbba6eacebd5d399185d3ee77c  bluez-qt-6.14.0.tar.xz
+ca2ed78578d1ac4cddaa283f3a7ba8f4  kfilemetadata-6.14.0.tar.xz
+9b13e46068bda372c5abc118e141316c  baloo-6.14.0.tar.xz
+#b132c475a7e389e6f7d36323279a7f3d  breeze-icons-6.14.0.tar.xz
+a435b2ac9c5bc4dff5cd5b8ad38653a3  krunner-6.14.0.tar.xz
+3c30dc5e69ebfd30f06de00a9e54f902  prison-6.14.0.tar.xz
+6d7743494d896980884e2c1e8d1d1ebf  qqc2-desktop-style-6.14.0.tar.xz
+7c445704ee24d5755714eaf86ea340ea  kholidays-6.14.0.tar.xz
+a19adf09478daf3e6fcd7bafee1f3a8f  purpose-6.14.0.tar.xz
+cbd3ae04c0b2093c414f908daa4589bf  kcalendarcore-6.14.0.tar.xz
+e955da56de5606fd74cab7eacc4576e8  kquickcharts-6.14.0.tar.xz
+56c871dd8b59d1211feabb2da8087e42  knotifyconfig-6.14.0.tar.xz
+692b832a4d11c83f4c6ec0868c91effb  kdav-6.14.0.tar.xz
+80f2ea5c5b6901c3415a64d5ee0429b2  kstatusnotifieritem-6.14.0.tar.xz
+e0e6deb2ef044df77dbc848002bf60aa  ksvg-6.14.0.tar.xz
+7e1542d5a1ba7ab659a6a334425a4df9  ktexttemplate-6.14.0.tar.xz
+975214cc75bfadb9464174f78f1548ba  kuserfeedback-6.14.0.tar.xz
 EOF
 
-[ -h /opt/kf6 ] && unlink /opt/kf6
-
-[ -d /opt/kf6.old ] && rm -r /opt/kf6.old
-
-if [ -d /opt/kf6 ]; then
-	mv -v /opt/kf6 /opt/kf6.old                         &&
-	install -v -dm755           $KF6_PREFIX/{etc,share} &&
-	ln -sfv /etc/dbus-1         $KF6_PREFIX/etc         &&
-	ln -sfv /usr/share/dbus-1   $KF6_PREFIX/share       &&
-	ln -sfv /usr/share/polkit-1 $KF6_PREFIX/share       &&
-	install -v -dm755           $KF6_PREFIX/lib         &&
-	ln -sfv /usr/lib/systemd    $KF6_PREFIX/lib
-fi
-
 while read -r line; do
 
     # Get the file name, ignoring comments and blank lines
@@ -225,6 +228,7 @@ done < frameworks-${EXT_VERSION}.md5
 rm -rf $KF6_PREFIX/lib/systemd
 
 mv -v /opt/kf6 /opt/kf6-${EXT_VERSION}
-ln -sfvn kf6-${EXT_VERSION} /opt/kf6
+[ -h /opt/kf6 ] && unlink /opt/kf6
+ln -sfvn /opt/kf6-${EXT_VERSION} /opt/kf6
 
 update_version_list kde_framework-${EXT_VERSION}
